﻿using System;
using System.Collections.Generic;
using System.Text;
using GenerateExecutionSnapshot.ReportService2005;

namespace GenerateExecutionSnapshot
{
    class Program
    {
        static void Main(string[] args)
        {

            bool forRendering = false;
            string historyID = null;
            ParameterValue[] values = null;
            DataSourceCredentials[] credentials = null;
            Warning[] warnings = null;
            bool keepExecutionShapshots = false;
            ScheduleDefinitionOrReference schedule = null;
            string reportPath = "/AMRS/Cache Demo";

            ReportingService2005 rs = new ReportingService2005();
            rs.Credentials = System.Net.CredentialCache.DefaultCredentials;

            // Check the execution options of the report (live or snapshot)
            ExecutionSettingEnum executionOption = rs.GetExecutionOptions(reportPath, out schedule);
            if (executionOption == ExecutionSettingEnum.Live) throw new ApplicationException(String.Format("Report {0} is not configured for snapshot execution", reportPath));

            ReportParameter[] parameters = rs.GetReportParameters(reportPath, historyID, forRendering, values, credentials);
            parameters[0].DefaultValues[0] = "2002";

            // All parameters have to be assigned default values before snapshot is generated 
            rs.SetReportParameters(reportPath, parameters);

            // Create the report snapshot
            rs.UpdateReportExecutionSnapshot(reportPath);

            // Check if the report is configured to keep snapshots in history
            bool result = rs.GetReportHistoryOptions(reportPath, out keepExecutionShapshots, out schedule);

            if (keepExecutionShapshots)
            {
                // history is automatically created, get the list of history runs
                ReportHistorySnapshot[] history = rs.ListReportHistory(reportPath);
                // Need to sort by date since history runs may not be chronologically sorted
                Array.Sort(history, CompareReportHistoryByDate);
                historyID = history[history.Length - 1].HistoryID; //grab the last history run
            }
            else
            {
                // explicitly create history snapshot
                historyID = rs.CreateReportHistorySnapshot(reportPath, out warnings);
            }
        }
        private static int CompareReportHistoryByDate(ReportHistorySnapshot x, ReportHistorySnapshot y)
        {
            return x.CreationDate < y.CreationDate ? -1 : 1;
        }


    }
}
