﻿using System;
using System.Collections.Generic;
using System.Text;
using GenerateExecutionSnapshot.ReportService2005;

namespace GenerateExecutionSnapshot
{
    class Program
    {
        static void Main(string[] args)
        {
            bool forRendering = false;
            string historyID = null;
            ParameterValue[] values = null;
            DataSourceCredentials[] credentials = null;
            Warning[] warnings = null;
            bool keepExecutionShapshots = false;
            ScheduleDefinitionOrReference schedule = null;
            string reportPath = "/AMRS/Cache Demo";
            ExecutionSettingEnum executionOption;

            ReportingService2005SoapClient rs = new ReportingService2005SoapClient();
            rs.ClientCredentials.Windows.AllowedImpersonationLevel = System.Security.Principal.TokenImpersonationLevel.Impersonation;
            ServerInfoHeader header = rs.GetExecutionOptions(reportPath, out executionOption, out schedule);

            if (executionOption == ExecutionSettingEnum.Live) throw new ApplicationException(String.Format("Report {0} is not configured for snapshot execution", reportPath));

            ReportParameter[] parameters;
            header = rs.GetReportParameters(reportPath, historyID, forRendering, values, credentials, out parameters);
            parameters[0].DefaultValues[0] = "2002";

            // All parameters have to be assigned default values before snapshot is generated 
            header = rs.SetReportParameters(null, reportPath, parameters);

            // Create the report snapshot
            header = rs.UpdateReportExecutionSnapshot(null, reportPath);

            // Check if the report is configured to keep snapshots in history
            bool result; 
            header = rs.GetReportHistoryOptions(reportPath, out result, out keepExecutionShapshots, out schedule);

            if (keepExecutionShapshots)
            {
                // history is automatically created, get the list of history runs
                ReportHistorySnapshot[] history;
                header = rs.ListReportHistory(reportPath, out history);
                // Need to sort by date since history runs may not be chronologically sorted
                Array.Sort(history, CompareReportHistoryByDate);
                historyID = history[history.Length - 1].HistoryID; //grab the last history run
            }
            else
            {
                // explicitly create history snapshot
                header = rs.CreateReportHistorySnapshot(null, reportPath, out historyID, out warnings);
            }
        }
        private static int CompareReportHistoryByDate(ReportHistorySnapshot x, ReportHistorySnapshot y)
        {
            return x.CreationDate < y.CreationDate ? -1 : 1;
        }
    }
}
