#region Namespaces
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Xml;
using System.IO;
using System.Net;
using System.Text;
using System.IO.IsolatedStorage;
using System.Diagnostics;
using System.Web;
using System.Web.Services.Protocols;
using WinReporter.Entities;
using Microsoft.Reporting.WinForms;
using RS = WinReporter.ReportService;
#endregion Namespaces

namespace WinReporter
{
	/// <summary>
	/// Summary description for AccessOptons.
	/// </summary>
	public class Main : System.Windows.Forms.Form
	{
        #region Class Members
		private System.Windows.Forms.Label lblFolder;
		private System.Windows.Forms.Label lblServer;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.GroupBox grpProcessingMode;
        private System.Windows.Forms.RadioButton radRemote;
		private System.Windows.Forms.GroupBox groupBox3;
		private System.Windows.Forms.Button btnRun;
		private System.Windows.Forms.TextBox txtFolder;
        private System.Windows.Forms.TextBox txtServer;
        private ComboBox cmbReports;
        private Label label1;
        private IContainer components;
        private RadioButton radLocal;
        private DataGrid grdParams;
        private Microsoft.Reporting.WinForms.ReportViewer reportViewer;
        private ToolTip toolTip;
        private const string ROOT_PREFIX = "img";
        #endregion Class members
        #region Properties
        /// <summary>
        /// Report path
        /// </summary>
        private string ReportPath
        {
            get
            {
                if (radRemote.Checked)
                    return String.Format("{0}/{1}", txtFolder.Text, cmbReports.Text);
                else
                    return String.Format("{0}/Reports/{1}.rdlc", Application.StartupPath, cmbReports.Text);
            }
        }

        /// <summary>
        /// The ReportViewer processing mode
        /// </summary>
        internal ProcessingMode ProcessingMode
        {
            get
            {
                return radRemote.Checked?ProcessingMode.Remote:ProcessingMode.Local;
            }

        }
        #endregion Properties
        #region Remote Processing
       /// <summary>
        /// Loads reports from the report catalog using the ListChildren API.
        /// </summary>
        private void LoadServerReports()
        {
            cmbReports.Items.Clear();

            RS.ReportingService2005 rs = new RS.ReportingService2005();
            rs.Credentials = System.Net.CredentialCache.DefaultCredentials;
            
            try
            {
                RS.CatalogItem[] items = rs.ListChildren(txtFolder.Text, false);

                foreach (RS.CatalogItem item in items)
                {
                    if (item.Type == ReportService.ItemTypeEnum.Report) cmbReports.Items.Add(item.Name);
                }

                if (cmbReports.Items.Count > 0) cmbReports.SelectedIndex = 0;
            }
            catch (Exception ex)
            {
                Util.ShowErrorMessage(ex.Message);
            }
        }
        /// <summary>
        /// Loads report parameters from the Execution endpoint
        /// </summary>
        private ReportParameterInfoCollection LoadRemoteReportParameters()
        {
            ResetReportViewer();
            reportViewer.ProcessingMode = ProcessingMode.Remote;
            reportViewer.ServerReport.ReportPath = this.ReportPath;
            // Uncomment the next two lines to localize ReportViewer
            // Done here to avoid "The source of the report definition has not been specified" error
            //ReportViewerCustomMessages myMessageClass = new ReportViewerCustomMessages();
            //reportViewer.Messages = myMessageClass;
            return reportViewer.ServerReport.GetParameters();
            
        }

        /// <summary>
        /// Runs a remote report
        /// </summary>
        internal void RunRemote()
        {
            try
            {
                ResetReportViewer();
                reportViewer.ProcessingMode = ProcessingMode.Remote;
                reportViewer.ServerReport.ReportPath = this.ReportPath;
                // Configure parameters
                ReportParameter[] parameters = UserParametersToReportParameters();
                reportViewer.ServerReport.SetParameters(parameters);
                reportViewer.RefreshReport();

            }
            catch (Exception ex)
            {
                // Normally, we shouldn't reach the catch block, since exceptions are handled by the report viewer
                // and error messages are displayed in the report pane. 
                throw ex;
            }
        }
        #endregion Remote Processing
        #region Local Processing
        /// <summary>
        /// Loads local report files (*.rdlc) from the applicaton startup folder
        /// </summary>
        private void LoadLocalReports()
        {
            cmbReports.Items.Clear();

            string[] reports = Directory.GetFiles(Application.StartupPath + @"\Reports", "customer orders.rdlc");

            foreach (string report in reports)
            {
                cmbReports.Items.Add(Path.GetFileNameWithoutExtension(report));
            }
            if (cmbReports.Items.Count > 0) cmbReports.SelectedIndex = 0;
        }
        /// <summary>
        /// Loads report parameters from the Execution endpoint
        /// </summary>
        private ReportParameterInfoCollection LoadLocalReportParameters()
        {
            ResetReportViewer();
            reportViewer.ProcessingMode = this.ProcessingMode;
            reportViewer.LocalReport.ReportPath = this.ReportPath;
            reportViewer.LocalReport.EnableExternalImages = true;
            reportViewer.LocalReport.EnableHyperlinks = true;
            return reportViewer.LocalReport.GetParameters();
        }
        /// <summary>
        /// Runs a remote report
        /// </summary>
        internal void RunLocal()
        {
            ResetReportViewer();
            reportViewer.ProcessingMode = ProcessingMode.Local;
            // Set report path
            reportViewer.LocalReport.ReportPath = this.ReportPath;
            // Enable hyperlinks to handle clicking on the Customer ID
            reportViewer.LocalReport.EnableHyperlinks = true;
            // Required since the logo image in Customer Orders report is external
            reportViewer.LocalReport.EnableExternalImages = true;
            // Required since the Custom Orders report is using a custom function to access the external image
            reportViewer.LocalReport.ExecuteReportInCurrentAppDomain(
                System.Reflection.Assembly.GetExecutingAssembly().Evidence);

            // Add report parameters
            ReportParameter[] parameters = this.UserParametersToReportParameters();
            reportViewer.LocalReport.SetParameters(parameters);

            // Bind data
            reportViewer.LocalReport.DataSources.Add(GetCustomers(parameters[0]));
            reportViewer.RefreshReport();
        }

        private ReportDataSource GetCustomers(ReportParameter customers)
        {
            string criteria = null;
            // Get the application dataset. In real life, the dataset would probably come from the business logic layer
            foreach (String value in customers.Values)
            {
                criteria += "," + value;
            }
            criteria = criteria.Remove(0, 1);  // remove trailing ","
            // Need to use a custom adapter to handle the IN clause in the SQL statement
            MyCustomerAdapter adapter = new MyCustomerAdapter(criteria);
            CustomerOrders.CustomerOrdersDataTable table = adapter.GetData();
            // Only one dataset is required for for this report
            return new ReportDataSource("dsOrders", table);
        }

        private void reportViewer_Drillthrough(object sender, DrillthroughEventArgs e)
        {
            // Handle local drillthrough only
            if (e.Report is ServerReport) return;

            LocalReport localReport = (LocalReport)e.Report;
            // Sales Order Detail local report takes two datasets
            // Load the Sales Order dataset
            Entities.SalesOrderTableAdapters.OrderTableAdapter orderAdapter = new Entities.SalesOrderTableAdapters.OrderTableAdapter();
            SalesOrder.OrderDataTable orderTable = orderAdapter.GetData(localReport.OriginalParametersToDrillthrough[0].Values[0]);
            // Load the Sales Order Detail dataset
            Entities.SalesOrderDetailTableAdapters.OrderDetailTableAdapter orderDetailAdapter = new Entities.SalesOrderDetailTableAdapters.OrderDetailTableAdapter();
            SalesOrderDetail.OrderDetailDataTable orderDetailTable = orderDetailAdapter.GetData(localReport.OriginalParametersToDrillthrough[0].Values[0]);

            localReport.DataSources.Add(new ReportDataSource("SalesOrder", orderTable));
            localReport.DataSources.Add(new ReportDataSource("SalesOrderDetail", orderDetailTable));
        }
        private void reportViewer_Hyperlink(object sender, HyperlinkEventArgs e)
        {
            Uri uri = new Uri(e.Hyperlink);
            if (String.Compare(uri.Scheme, "customerid", StringComparison.OrdinalIgnoreCase)==0)
            {
                e.Cancel = true;
                MessageBox.Show(String.Format("Display data for customer: {0}", System.Web.HttpUtility.UrlDecode(uri.AbsolutePath)));
                ((ReportViewer)sender).RefreshReport();
            }
        }
        #endregion Local Processing
        #region Helper Methods
        private void LoadReports()
        {
            if (this.ProcessingMode == ProcessingMode.Remote)
                LoadServerReports();
            else
                LoadLocalReports();
        }

        private void LoadReportParameters()
        {
            EntityParameter.ParametersDataTable userParameters;
            ReportParameterInfoCollection reportViewerParameters;

            if (this.ProcessingMode == ProcessingMode.Remote)
                reportViewerParameters = LoadRemoteReportParameters();
            else
                reportViewerParameters = LoadLocalReportParameters();

            userParameters = ReportParametersToUserParameters(reportViewerParameters);
            userParameters.DefaultView.AllowNew = false;
            userParameters.DefaultView.AllowDelete = false;
            userParameters.Columns[0].ReadOnly = true;
            grdParams.DataSource = userParameters;
        }
        private EntityParameter.ParametersDataTable ReportParametersToUserParameters(ReportParameterInfoCollection reportViewerParameters)
        {
            EntityParameter.ParametersDataTable userParameters = new EntityParameter.ParametersDataTable();


            foreach (ReportParameterInfo p in reportViewerParameters)
            {
                string[] values = new string[p.Values.Count];
                for (int i = 0; i < p.Values.Count; i++)
                {
                    values[i] = p.Values[i];
                }
                userParameters.Rows.Add(p.Name, String.Join(",", values));
            }
            return userParameters;
        }
        private ReportParameter[] UserParametersToReportParameters()
        {

            EntityParameter.ParametersDataTable userParameters = (EntityParameter.ParametersDataTable)grdParams.DataSource;
            ReportParameterInfoCollection reportParameters = this.ProcessingMode == ProcessingMode.Remote ?
                reportViewer.ServerReport.GetParameters() : reportViewer.LocalReport.GetParameters();

            ReportParameter[] parameters = new ReportParameter[reportParameters.Count];

            for (int i = 0; i < reportParameters.Count; i++)
            {
                EntityParameter.ParametersRow p = (EntityParameter.ParametersRow)userParameters.Rows[i];
                if (reportParameters[i].MultiValue)
                    parameters[i] = new ReportParameter(p.Name, p.Value.Split(new char[] { ',' }));
                else
                    parameters[i] = new ReportParameter(p.Name, p.Value);

            }
            return parameters;
        }
        /// <summary>
		/// Gets the user settings from isolated storage
		/// </summary>
		private void LoadUserSettings() 
		{
			try 
			{
				XmlDocument dom = new XmlDocument();
				using (Stream s = Util.GetSettingsStream(this.Name, FileMode.Open, FileAccess.Read, FileShare.Read)) 
				{
					dom.Load(s);
				}
				txtServer.Text		= dom.SelectSingleNode("//serverUrl").InnerText;
				txtFolder.Text		= dom.SelectSingleNode("//reportPath").InnerText;
			}
			catch {}  // no big deal if we fail - this is a convenience feature only
		}
		/// <summary>
		/// Saves the user preferences to the isolated storage
		/// </summary>
		void SaveUserSettings() 
		{
			try 
			{
				using (Stream s = Util.GetSettingsStream(this.Name, FileMode.Create, FileAccess.ReadWrite, FileShare.None)) 
				{
					XmlTextWriter w = new XmlTextWriter(s, System.Text.Encoding.UTF8);
					w.WriteStartElement(this.Name);
					w.WriteElementString("serverUrl",  txtServer.Text);
					w.WriteElementString("reportPath", txtFolder.Text);
					w.WriteEndElement();
					w.Close();
				}
			}
			catch {}  // no big deal if we fail - this is a convenience feature only

        }

        #endregion Helper methods
        #region Events        
        private void WinReporter_Load(object sender, System.EventArgs e)
		{
            try
            {
                this.Cursor = Cursors.WaitCursor;
                // Get the Report Server endpoint from the config file
                txtServer.Text = Properties.Settings.Default.ReportServerUrl;
                txtFolder.Text = Properties.Settings.Default.ReportPath;
                reportViewer.ServerReport.ReportServerUrl = new Uri(Properties.Settings.Default.ReportServerUrl);
                LoadUserSettings();
                LoadReports();
                ConfigureUI();
                btnRun.Focus();
                btnRun.Select();
            }

            finally
            {
                this.Cursor = Cursors.Default;
            }

		}
        private void ConfigureUI()
        {
            cmbReports.Enabled = cmbReports.Items.Count > 0;
            btnRun.Enabled = cmbReports.Items.Count>0;
        }
        private void btnGetReports_Click(object sender, EventArgs e)
        {
            try
            {
                this.Cursor = Cursors.WaitCursor;
                LoadReports();
                if (cmbReports.SelectedIndex > -1) LoadReportParameters();
                ConfigureUI();
            }
            finally
            {
                this.Cursor = Cursors.Default;
            }
        }
        private void btnRun_Click(object sender, System.EventArgs e)
        {
            try
            {
                if (this.ProcessingMode == ProcessingMode.Remote)
                    RunRemote();
                else
                    RunLocal();

            }
            finally
            {
                this.Cursor = Cursors.Default;
            }
        }

		private void WinReporter_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			SaveUserSettings();
		}



        private void cmbReports_SelectedIndexChanged(object sender, EventArgs e)
        {

            if (!cmbReports.Enabled) return;
            ResetReportViewer();
            
            reportViewer.RefreshReport();
            LoadReportParameters();
        }

        private void ResetReportViewer()
        {
            Uri u = reportViewer.ServerReport.ReportServerUrl; // save report server url
            reportViewer.Reset();
            reportViewer.ServerReport.ReportServerUrl = u;
        }

        private void ProcessingMode_CheckedChanged(object sender, EventArgs e)
        {
            LoadReports();
        }
        #endregion Events
        #region Security
        /// <summary>
        /// Demonstrates configuring the Report Viewer control for basic security
        /// Make sure to enable Basic Security in IIS for /ReportServer vroot and 
        /// change credentials in CredentialCache below 
        /// </summary>
        private void SetBasicSecurity()
        {
            reportViewer.ServerReport.ReportServerCredentials.NetworkCredentials = new NetworkCredential("Bob", "P@ssw0rd");
            //  alternatively:
            //  CredentialCache cc = new CredentialCache();
            //  cc.Add(new Uri(Properties.Settings.Default.ReportServerUrl), "Basic", new NetworkCredential("Bob", "P@ssw0rd"));
            //  reportViewer.ServerReport.ReportServerCredentials.NetworkCredentials = cc;
        }

        /// <summary>
        /// Configuring custom security by passing the user name and password explicitly
        /// </summary>
        private void SetCustomSecurity1()
        {
            reportViewer.ServerReport.ReportServerCredentials.SetFormsCredentials(null, "rs", "rs", null);

            // you can get user credentials at some later time
            //Cookie cookie = null;
            //string userName, pwd, authority = null;
            //reportViewer.ServerReport.ReportServerCredentials.GetFormsCredentials(out cookie, out userName, out pwd, out authority);
        }
        /// <summary>
        /// Configuring custom security by calling LogonUser and caching the auth ticket
        /// </summary>
        private void SetCustomSecurity2()
        {
            ReportServerProxy rs = new ReportServerProxy();
            rs.LogonUser("rs", "rs", null);
            reportViewer.ServerReport.ReportServerCredentials.SetFormsCredentials(ReportServerProxy.AuthCookie, null, null, null);

            // you can get back the cookie at some later time
            //Cookie cookie = null;
            //string userName, pwd, authority = null;
            //reportViewer.ServerReport.ReportServerCredentials.GetFormsCredentials(out cookie, out userName, out pwd, out authority);
        }
        /// <summary>
        /// Needed only if you call LogonUser EXPLICITLY
        /// </summary>
        public class ReportServerProxy : RS.ReportingService2005
        {
            private static Cookie m_Authcookie = null;
            protected override WebRequest GetWebRequest(Uri uri)
            {
                HttpWebRequest request;
                request = (HttpWebRequest)HttpWebRequest.Create(uri);
                // Create a cookie jar to hold the request cookie
                CookieContainer cookieJar = new CookieContainer();
                request.CookieContainer = cookieJar;
                Cookie authCookie = AuthCookie;
                // if the LogonUser SOAP API has been called already
                // get the cookie and place it in the request's cookie container
                if (authCookie != null)
                    request.CookieContainer.Add(authCookie);
                request.Timeout = -1;
                request.Headers.Add("Accept-Language", System.Windows.Forms.Application.CurrentCulture.Name);
                return request;
            }

            protected override WebResponse GetWebResponse(WebRequest request)
            {
                WebResponse response = base.GetWebResponse(request);
                string cookieName = response.Headers["RSAuthenticationHeader"];
                // If the response contains an auth header, store the cookie
                if (cookieName != null)
                {
                    Util.CustomAuthCookieName = cookieName;
                    HttpWebResponse webResponse = (HttpWebResponse)response;
                    Cookie authCookie = webResponse.Cookies[cookieName];
                    // If the auth cookie is null, throw an exception
                    if (authCookie == null)
                    {
                        throw new Exception(
                            "Authorization ticket not received by LogonUser");
                    }
                    // otherwise save it for this request
                    AuthCookie = authCookie;
                    // and send it to the client
                    //Utilities.RelayCookieToClient(authCookie);
                }
                return response;
            }

            internal static Cookie AuthCookie
            {
                get
                {
                    return m_Authcookie;
                }
                set
                {
                    m_Authcookie = value;
                }
            }


        }

        #endregion
		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.components = new System.ComponentModel.Container();
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(Main));
            this.txtFolder = new System.Windows.Forms.TextBox();
            this.lblFolder = new System.Windows.Forms.Label();
            this.btnRun = new System.Windows.Forms.Button();
            this.lblServer = new System.Windows.Forms.Label();
            this.txtServer = new System.Windows.Forms.TextBox();
            this.groupBox1 = new System.Windows.Forms.GroupBox();
            this.cmbReports = new System.Windows.Forms.ComboBox();
            this.grpProcessingMode = new System.Windows.Forms.GroupBox();
            this.radLocal = new System.Windows.Forms.RadioButton();
            this.radRemote = new System.Windows.Forms.RadioButton();
            this.label1 = new System.Windows.Forms.Label();
            this.groupBox3 = new System.Windows.Forms.GroupBox();
            this.grdParams = new System.Windows.Forms.DataGrid();
            this.reportViewer = new Microsoft.Reporting.WinForms.ReportViewer();
            this.toolTip = new System.Windows.Forms.ToolTip(this.components);
            this.groupBox1.SuspendLayout();
            this.grpProcessingMode.SuspendLayout();
            this.groupBox3.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.grdParams)).BeginInit();
            this.SuspendLayout();
            // 
            // txtFolder
            // 
            this.txtFolder.Location = new System.Drawing.Point(86, 50);
            this.txtFolder.Name = "txtFolder";
            this.txtFolder.ReadOnly = true;
            this.txtFolder.Size = new System.Drawing.Size(132, 20);
            this.txtFolder.TabIndex = 1;
            this.txtFolder.Text = "/AMRS";
            this.toolTip.SetToolTip(this.txtFolder, "Change this value in app.config");
            // 
            // lblFolder
            // 
            this.lblFolder.Location = new System.Drawing.Point(16, 50);
            this.lblFolder.Name = "lblFolder";
            this.lblFolder.Size = new System.Drawing.Size(72, 16);
            this.lblFolder.TabIndex = 18;
            this.lblFolder.Text = "Folder:";
            // 
            // btnRun
            // 
            this.btnRun.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
            this.btnRun.Font = new System.Drawing.Font("Microsoft Sans Serif", 8F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.btnRun.Image = ((System.Drawing.Image)(resources.GetObject("btnRun.Image")));
            this.btnRun.ImageAlign = System.Drawing.ContentAlignment.MiddleLeft;
            this.btnRun.Location = new System.Drawing.Point(501, 72);
            this.btnRun.Name = "btnRun";
            this.btnRun.Size = new System.Drawing.Size(117, 23);
            this.btnRun.TabIndex = 14;
            this.btnRun.Text = "Run Report";
            this.btnRun.Click += new System.EventHandler(this.btnRun_Click);
            // 
            // lblServer
            // 
            this.lblServer.Location = new System.Drawing.Point(16, 24);
            this.lblServer.Name = "lblServer";
            this.lblServer.Size = new System.Drawing.Size(64, 20);
            this.lblServer.TabIndex = 20;
            this.lblServer.Text = "Server Url:";
            // 
            // txtServer
            // 
            this.txtServer.Location = new System.Drawing.Point(86, 24);
            this.txtServer.Name = "txtServer";
            this.txtServer.ReadOnly = true;
            this.txtServer.Size = new System.Drawing.Size(224, 20);
            this.txtServer.TabIndex = 0;
            this.txtServer.Text = "http://localhost/reportserver";
            this.toolTip.SetToolTip(this.txtServer, "Change this value in app.config");
            // 
            // groupBox1
            // 
            this.groupBox1.Controls.Add(this.cmbReports);
            this.groupBox1.Controls.Add(this.grpProcessingMode);
            this.groupBox1.Controls.Add(this.label1);
            this.groupBox1.Controls.Add(this.lblServer);
            this.groupBox1.Controls.Add(this.txtServer);
            this.groupBox1.Controls.Add(this.lblFolder);
            this.groupBox1.Controls.Add(this.txtFolder);
            this.groupBox1.Location = new System.Drawing.Point(8, 8);
            this.groupBox1.Name = "groupBox1";
            this.groupBox1.Size = new System.Drawing.Size(631, 108);
            this.groupBox1.TabIndex = 21;
            this.groupBox1.TabStop = false;
            this.groupBox1.Text = "Report";
            // 
            // cmbReports
            // 
            this.cmbReports.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.cmbReports.Location = new System.Drawing.Point(86, 76);
            this.cmbReports.Name = "cmbReports";
            this.cmbReports.Size = new System.Drawing.Size(224, 21);
            this.cmbReports.TabIndex = 3;
            this.toolTip.SetToolTip(this.cmbReports, "Select a report to run");
            this.cmbReports.SelectedIndexChanged += new System.EventHandler(this.cmbReports_SelectedIndexChanged);
            // 
            // grpProcessingMode
            // 
            this.grpProcessingMode.Controls.Add(this.radLocal);
            this.grpProcessingMode.Controls.Add(this.radRemote);
            this.grpProcessingMode.Location = new System.Drawing.Point(329, 24);
            this.grpProcessingMode.Name = "grpProcessingMode";
            this.grpProcessingMode.Size = new System.Drawing.Size(153, 73);
            this.grpProcessingMode.TabIndex = 23;
            this.grpProcessingMode.TabStop = false;
            this.grpProcessingMode.Text = "Report Processing Mode";
            this.toolTip.SetToolTip(this.grpProcessingMode, "Choose remote or local report processing mode");
            // 
            // radLocal
            // 
            this.radLocal.Location = new System.Drawing.Point(8, 42);
            this.radLocal.Name = "radLocal";
            this.radLocal.Size = new System.Drawing.Size(132, 24);
            this.radLocal.TabIndex = 11;
            this.radLocal.Text = "Local Mode";
            this.radLocal.CheckedChanged += new System.EventHandler(this.btnGetReports_Click);
            // 
            // radRemote
            // 
            this.radRemote.Checked = true;
            this.radRemote.Location = new System.Drawing.Point(8, 21);
            this.radRemote.Name = "radRemote";
            this.radRemote.Size = new System.Drawing.Size(132, 24);
            this.radRemote.TabIndex = 10;
            this.radRemote.TabStop = true;
            this.radRemote.Text = "Remote Mode";
            this.radRemote.CheckedChanged += new System.EventHandler(this.btnGetReports_Click);
            // 
            // label1
            // 
            this.label1.Location = new System.Drawing.Point(16, 79);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(64, 16);
            this.label1.TabIndex = 23;
            this.label1.Text = "Report:";
            // 
            // groupBox3
            // 
            this.groupBox3.Controls.Add(this.grdParams);
            this.groupBox3.Controls.Add(this.btnRun);
            this.groupBox3.Location = new System.Drawing.Point(8, 121);
            this.groupBox3.Name = "groupBox3";
            this.groupBox3.Size = new System.Drawing.Size(631, 101);
            this.groupBox3.TabIndex = 24;
            this.groupBox3.TabStop = false;
            this.groupBox3.Text = "Parameters";
            // 
            // grdParams
            // 
            this.grdParams.DataMember = "";
            this.grdParams.FlatMode = true;
            this.grdParams.HeaderForeColor = System.Drawing.SystemColors.ControlText;
            this.grdParams.Location = new System.Drawing.Point(8, 13);
            this.grdParams.Name = "grdParams";
            this.grdParams.PreferredColumnWidth = 150;
            this.grdParams.Size = new System.Drawing.Size(474, 82);
            this.grdParams.TabIndex = 22;
            this.toolTip.SetToolTip(this.grdParams, "Enter the values of the report parameters");
            // 
            // reportViewer
            // 
            this.reportViewer.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.reportViewer.LocalReport.ReportEmbeddedResource = "WinReporter.Reports.Customer Orders.rdlc";
            this.reportViewer.Location = new System.Drawing.Point(8, 228);
            this.reportViewer.Name = "reportViewer";
            this.reportViewer.ServerReport.ReportServerUrl = new System.Uri("", System.UriKind.Relative);
            this.reportViewer.Size = new System.Drawing.Size(631, 369);
            this.reportViewer.TabIndex = 25;
            this.reportViewer.Hyperlink += new Microsoft.Reporting.WinForms.HyperlinkEventHandler(this.reportViewer_Hyperlink);
            this.reportViewer.Drillthrough += new Microsoft.Reporting.WinForms.DrillthroughEventHandler(this.reportViewer_Drillthrough);
            // 
            // Main
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(643, 609);
            this.Controls.Add(this.reportViewer);
            this.Controls.Add(this.groupBox3);
            this.Controls.Add(this.groupBox1);
            this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
            this.Name = "Main";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Text = "WinReporter";
            this.Load += new System.EventHandler(this.WinReporter_Load);
            this.groupBox1.ResumeLayout(false);
            this.groupBox1.PerformLayout();
            this.grpProcessingMode.ResumeLayout(false);
            this.groupBox3.ResumeLayout(false);
            ((System.ComponentModel.ISupportInitialize)(this.grdParams)).EndInit();
            this.ResumeLayout(false);

		}
        /// <summary>
        /// Clean up any resources being used.
        /// </summary>
        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                if (components != null)
                {
                    components.Dispose();
                }
            }
            base.Dispose(disposing);
        }
        public Main()
        {
            //
            // Required for Windows Form Designer support
            //
            InitializeComponent();
            //
            // TODO: Add any constructor code after InitializeComponent call
            //
        }
		#endregion
    }
#region IReportViewerMessages Members
    public class ReportViewerCustomMessages : IReportViewerMessages, IReportViewerMessages2
    {
        public string BackButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string BackMenuItemText
        {
            get { return("Add your custom text here."); }
        }

        public string ChangeCredentialsText
        {
            get { return("Add your custom text here."); }
        }

        public string CurrentPageTextBoxToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string DocumentMapButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string DocumentMapMenuItemText
        {
            get { return("Add your custom text here."); }
        }

        public string ExportButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string ExportMenuItemText
        {
            get { return("Add your custom text here."); }
        }

        public string FalseValueText
        {
            get { return("Add your custom text here."); }
        }

        public string FindButtonText
        {
            get { return("Add your custom text here."); }
        }

        public string FindButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string FindNextButtonText
        {
            get { return("Add your custom text here."); }
        }

        public string FindNextButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string FirstPageButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string LastPageButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string NextPageButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string NoMoreMatches
        {
            get { return("Add your custom text here."); }
        }

        public string NullCheckBoxText
        {
            get { return("Add your custom text here."); }
        }

        public string NullCheckBoxToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string NullValueText
        {
            get { return("Add your custom text here."); }
        }

        public string PageOf
        {
            get { return("Add your custom text here."); }
        }

        public string PageSetupButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string PageSetupMenuItemText
        {
            get { return("Add your custom text here."); }
        }

        public string ParameterAreaButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string PasswordPrompt
        {
            get { return("Add your custom text here."); }
        }

        public string PreviousPageButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string PrintButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string PrintLayoutButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string PrintLayoutMenuItemText
        {
            get { return("Add your custom text here."); }
        }

        public string PrintMenuItemText
        {
            get { return("Add your custom text here."); }
        }

        public string ProgressText
        {
            get { return("Add your custom text here."); }
        }

        public string RefreshButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string RefreshMenuItemText
        {
            get { return("Add your custom text here."); }
        }

        public string SearchTextBoxToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string SelectAValue
        {
            get { return("Add your custom text here."); }
        }

        public string SelectAll
        {
            get { return("Add your custom text here."); }
        }

        public string StopButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string StopMenuItemText
        {
            get { return("Add your custom text here."); }
        }

        public string TextNotFound
        {
            get { return("Add your custom text here."); }
        }

        public string TotalPagesToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string TrueValueText
        {
            get { return("Add your custom text here."); }
        }

        public string UserNamePrompt
        {
            get { return("Add your custom text here."); }
        }

        public string ViewReportButtonText
        {
            get { return("Add your custom text here."); }
        }

        public string ViewReportButtonToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string ZoomControlToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string ZoomMenuItemText
        {
            get { return("Add your custom text here."); }
        }

        public string ZoomToPageWidth
        {
            get { return("Add your custom text here."); }
        }

        public string ZoomToWholePage
        {
            get { return("Add your custom text here."); }
        }

        #endregion

        #region IReportViewerMessages2 Members

        public string AllFilesFilter
        {
            get { return("Add your custom text here."); }
        }

        public string CredentialMissingUserNameError(string dataSourcePrompt)
        {
            return("Add your custom text here.");
        }

        public string DateToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string ExportErrorTitle
        {
            get { return("Add your custom text here."); }
        }

        public string FloatToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string GetLocalizedNameForRenderingExtension(string format)
        {
            return("Add your custom text here.");
        }

        public string HyperlinkErrorTitle
        {
            get { return("Add your custom text here."); }
        }

        public string IntToolTip
        {
            get { return("Add your custom text here."); }
        }

        public string MessageBoxTitle
        {
            get { return("Add your custom text here."); }
        }

        public string ParameterMissingSelectionError(string parameterPrompt)
        {
            return("Add your custom text here.");
        }

        public string ParameterMissingValueError(string parameterPrompt)
        {
            return("Add your custom text here.");
        }

        public string ProcessingStopped
        {
            get { return("Add your custom text here."); }
        }

        public string PromptAreaErrorTitle
        {
            get { return("Add your custom text here."); }
        }

        public string StringToolTip
        {
            get { return("Add your custom text here."); }
        }

        
    }
#endregion
}
