using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.Threading;
using System.Diagnostics;
using System.Collections;
using Microsoft.AnalysisServices.AdomdClient;
using System.Security.Permissions;

namespace Prologika.RS.Extensibility
{
    public class Translator
    {
        static Hashtable cache = new Hashtable();

        public static string GetTranslatedCaption(string item)
        {
            string caption = null;
            try
            {
                // get language identifier, e.g. 1033 for En-US
                string lid = Thread.CurrentThread.CurrentUICulture.TextInfo.LCID.ToString();
                Trace.WriteLine(String.Format("Language ID: {0}", lid));

                // get cache identifier
                string cacheID = GetCacheIdentifier(item, lid);

                // attempt to get item from cache 
                caption = (string)cache[GetCacheIdentifier(item, lid)];

                if (caption == null)
                {
                    CacheMetadata(lid);
                    caption = (string)cache[GetCacheIdentifier(item, lid)];
                }
            }
            catch (Exception ex)
            {
                caption = ex.ToString();
            }
            return caption;
        }

        private static string GetCacheIdentifier(string item, string lid)
        {
            return String.Format("{0}-{1}", lid, item);
        }

        private static void CacheMetadata(string lid)
        {



            AdomdRestrictionCollection restrictions = new AdomdRestrictionCollection();
            DataSet ds = new DataSet();
            //AdomdConnection conn = new AdomdConnection(String.Format("Data Source=localhost;Catalog=Adventure Works DW;Locale Identifier={0};uid=nw8000\\sa;password=C3o7kCgC", lid));
            AdomdConnection conn = new AdomdConnection(String.Format(@"Data Source=localhost;Initial Catalog=Adventure Works DW;Integrated Security=SSPI;Locale Identifier={0};", lid));
            conn.Open();

            lock (cache.SyncRoot)
            {
                // cache dimensions 
                restrictions.Add("CUBE_SOURCE", 2);
                ds = conn.GetSchemaDataSet("MDSCHEMA_CUBES", restrictions);

                Trace.WriteLine("");
                Trace.WriteLine("Dimensions");
                foreach (DataRow row in ds.Tables[0].Rows)
                {
                    string cacheID = GetCacheIdentifier(row["CUBE_NAME"].ToString(), lid);
                    if (cache[cacheID] == null) cache.Add(cacheID, row["CUBE_CAPTION"].ToString());
                    Trace.Write(row["CUBE_CAPTION"].ToString().PadRight(20));
                }

                // cache all attributes
                Trace.WriteLine("");
                Trace.WriteLine("Hierarchies");
                restrictions.Clear();
                ds = conn.GetSchemaDataSet("MDSCHEMA_HIERARCHIES", restrictions);
                foreach (DataRow row in ds.Tables[0].Rows)
                {
                    string cacheID = GetCacheIdentifier(row["HIERARCHY_UNIQUE_NAME"].ToString(), lid);
                    if (cache[cacheID] == null) cache.Add(cacheID, row["HIERARCHY_CAPTION"].ToString());
                    Trace.Write(row["HIERARCHY_CAPTION"].ToString().PadRight(20));
                }

                // cache all measures
                Trace.WriteLine("");
                Trace.WriteLine("Measures");
                restrictions.Clear();
                ds = conn.GetSchemaDataSet("MDSCHEMA_MEASURES", restrictions);
                foreach (DataRow row in ds.Tables[0].Rows)
                {
                    string cacheID = GetCacheIdentifier(row["MEASURE_UNIQUE_NAME"].ToString(), lid);
                    if (cache[cacheID] == null) cache.Add(cacheID, row["MEASURE_CAPTION"].ToString());
                    Trace.Write(row["MEASURE_CAPTION"].ToString().PadRight(20));
                }
            }
        }
    }
}
