using System;
using System.IO;
using System.Xml;
using System.Reflection;
using System.Collections;
using System.Diagnostics;
using System.Drawing;
using System.Windows.Forms;
using Microsoft.ReportingServices.Interfaces;
using Microsoft.ReportingServices.DataProcessing;

namespace Prologika.RS.Extensibility.CustomDataProcessingExtension
{
    public class DatasetQueryDesigner : IQueryDesigner
    {
        private IDbConnection    _connection;
        private IDbCommand       _command;
        private IServiceProvider _serviceProvider;
        private ToolBar          _toolBar;
        private Form1  _form;
        private ToolBarButton    _openButton;
        private ToolBarButton    _executeButton;

        public DatasetQueryDesigner()
        {
            CreateToolBar();
            CreateQueryDesignerPanel();
        }

        private ImageList GetToolBarButtonImages()
        {
            Bitmap bm = new Bitmap(Assembly.GetExecutingAssembly().
                GetManifestResourceStream(Assembly.GetExecutingAssembly().GetTypes()[0].Namespace + ".buttons.bmp"));
            ImageList imglist = new ImageList();
            imglist.Images.AddStrip(bm);
            imglist.TransparentColor = Color.Cyan;
            return imglist;
        }

        private void CreateToolBar()
        {
            _toolBar = new ToolBar();
            _toolBar.ImageList = GetToolBarButtonImages();
            _toolBar.ShowToolTips = true;
            _toolBar.Appearance = ToolBarAppearance.Flat;

            _openButton = new ToolBarButton();
            _openButton.ImageIndex = 0;
            _openButton.ToolTipText = "Open";
            _toolBar.Buttons.Add(_openButton);

            _executeButton = new ToolBarButton();
            _executeButton.ImageIndex = 1;
            _executeButton.ToolTipText = "Execute";
            _toolBar.Buttons.Add(_executeButton);

            _toolBar.ButtonClick += new ToolBarButtonClickEventHandler(toolBar_ButtonClick);
        }

        private void CreateQueryDesignerPanel()
        {
            _form = new Form1();
        }

        #region IQueryDesigner Members

        public IDbCommand Command
        {
            get
            {
                UpdateCommandFromUI();
                return _command;
            }
            set
            {
                _command = value;
                UpdateUIFromCommand();
            }
        }

        public IServiceProvider ServiceProvider
        {
            set
            {
                _serviceProvider = value;
            }
        }

        public bool InitializeQueryDesigner()
        {
            return true;
        }

        public System.Windows.Forms.Control ToolBar
        {
            get
            {
                return _toolBar;
            }
        }

        public IDbConnection Connection
        {
            set
            {
                _connection = value;
            }
        }




        public void OnDeactivateView()
        {
            UpdateCommandFromUI(); 
        }


        public System.Windows.Forms.Control QueryDesigner
        {
            get
            {
                return _form.GetQueryDesignerPanel();
            }
        }

        public void OnActivateView()
        {
            UpdateUIFromCommand();
        }


        public event Microsoft.ReportingServices.Interfaces.EnableEventHandler EnableAltDesignerChanged;

        #endregion

        private void UpdateCommandFromUI()
        {
            _command.CommandText = String.Format("{0}{1}{2}", _form.FilePath, Util.PARAM_DELIMITER, _form.TableName);
        }

        private void UpdateUIFromCommand()
        {
            string[] parameters = _command.CommandText.Split((char)Util.PARAM_DELIMITER);
            _form.FilePath = parameters[0];
            _form.TableName = parameters.Length > 1 ? parameters[1] : String.Empty;
        }

        #region IDisposable Members

        public void Dispose()
        {
        }

        #endregion

        #region IExtension Members

        public string LocalizedName
        {
            get
            {
                return "Dataset Query Designer";
            }
        }

        public void SetConfiguration(string configuration)
        {
        }

        #endregion

        private void toolBar_ButtonClick(object sender, ToolBarButtonClickEventArgs e)
        {
            if (e.Button == _openButton)
            {
                _form.OpenFileBrowser();
            }
            else if (e.Button == _executeButton)
            {
                UpdateCommandFromUI();
                _form.ExecuteCommand(_command);
            }
        }
    }
}
