#region Disclaimer by Teo Lachev 
/*============================================================================
  File:      AuthenticationExtension.cs

  Summary:  Demonstrates an implementation of an authentication extension.
--------------------------------------------------------------------
  This code sample was built upon on the Microsoft Custom Security sample 
  http://tinyurl.com/33lhoy
 
  The following portions of the code have been changed/added to fit the book needs:
  1. The authentication logic has been changed to use the Individuals credential store 
	 from the AW2000 database.
  2. Added support for confguration settings, such as connection string, admin uid and pwd
===========================================================================*/
#endregion

using System;
using System.Xml;
using System.Data;
using System.Data.SqlClient;
using System.Security.Principal;
using System.Web;
using System.Globalization;
using Microsoft.ReportingServices.Interfaces;

namespace Prologika.RS.Extensibility.CustomSecurityExtension
{
   public class AuthenticationExtension : IAuthenticationExtension
   {
	   internal const string ADMIN_CONFIG = "AdminConfiguration";
	   internal const string CONNECTION_STRING = "ConnectionString";
	   internal const string ADMIN_USER_NAME = "AdminLogin";
	   internal const string ADMIN_USER_PWD = "AdminPassword";

	   private static string m_connectionstring = null;
	   private static string m_adminUserName = null;
	   private static string m_adminPassword = null;
      /// <summary>
      /// You must implement SetConfiguration as required by IExtension
      /// </summary>
      /// <param name="configuration">Configuration data as an XML
      /// string that is stored along with the Extension element in
      /// the configuration file.</param>
      public void SetConfiguration(String configuration)
      {
		  // Retrieve the connection string to the authorization store
		  XmlDocument doc = new XmlDocument();
		  doc.LoadXml(configuration);
		  if (doc.DocumentElement.Name == "AdminConfiguration")
		  {
			  foreach (XmlNode child in doc.DocumentElement.ChildNodes)
			  {
				  switch (child.Name)
				  {
						case CONNECTION_STRING		: m_connectionstring = child.InnerText; break;
						case ADMIN_USER_NAME		: m_adminUserName = child.InnerText; break;
						case ADMIN_USER_PWD			: m_adminPassword = child.InnerText; break;
						default						: throw new Exception("Unrecognized configuration element.");
				  }
			  }
		  }
		  else
			  throw new Exception("Loading config data.");
      }

      /// <summary>
      /// You must implement LocalizedName as required by IExtension
      /// </summary>
      public string LocalizedName 
      {
         get
         {
            return "Custom Authentication Extension";
         }
      }

      /// <summary>
      /// Indicates whether a supplied username and password are valid.
      /// </summary>
      /// <param name="userName">The supplied username</param>
      /// <param name="password">The supplied password</param>
      /// <param name="authority">Optional. The specific authority to use to
      /// authenticate a user. For example, in Windows it would be a Windows 
      /// Domain</param>
      /// <returns>true when the username and password are valid</returns>
      public bool LogonUser(string userName, string password, string authority)
      {
          if ((0 == String.Compare(userName, m_adminUserName, true, CultureInfo.CurrentCulture)) && (password == m_adminPassword))
              return true;
          else
              return AuthenticationUtilities.IsValidUser(userName, password, m_connectionstring);
      }  
      
      /// <summary>
      /// Required by IAuthenticationExtension. The report server calls the 
      /// GetUserInfo method for each request to retrieve the current user 
      /// identity.
      /// </summary>
      /// <param name="userIdentity">Represents the identity of the current 
      /// user. The value of IIdentity may appear in a user interface and 
      /// should be human readable</param>
      /// <param name="userId">represents a pointer to a unique user identity
      /// </param>
      public void GetUserInfo(out IIdentity userIdentity, out IntPtr userId)
      {
         // If the current user identity is not null,
         // set the userIdentity parameter to that of the current user 
         if (HttpContext.Current != null
               && HttpContext.Current.User != null)
         {
			 userIdentity = HttpContext.Current.User.Identity;
         }
         else
             userIdentity = null;

         // initialize a pointer to the current user id to zero
         userId = IntPtr.Zero;
      }

      /// <summary>
      /// The IsValidPrincipalName method is called by the report server when 
      /// the report server sets security on an item,e.g. when you add a new user to the folder security polity. 
      /// This method validates that the user name is valid. 
      /// </summary>
      /// <param name="principalName">A user, group, or built-in account name
      /// </param>
      /// <returns>true when the principle name is valid</returns>
      public bool IsValidPrincipalName(string principalName)
      {
         return AuthenticationUtilities.IsValidPrincipalName(principalName, m_connectionstring);
      }

	   internal static string ConnectionString
	   {
		   get
		   {
			   return m_connectionstring;
		   }
	   }	
	   internal static string AdminLogin
	   {
		   get
		   {
			   return m_adminUserName;
		   }
	   }
   }
}
