#region Disclaimer by Teo Lachev
/*============================================================================
  File:      WebServiceDeliveryUIControl.cs

  Summary:  Demonstrates an implementation of a custom delivery control for Report Manager.
--------------------------------------------------------------------
  This code sample was built upon on the Microsoft Printer Delivery Extension Sample 
  http://tinyurl.com/29jthp
 
  The following portions of the code have been changed/added to fit the book needs:
  1. The control accepts the web service endpoint and method name as input parameters
===========================================================================*/
#endregion
using System;
using System.IO;
using System.Web;
using System.Text;
using System.Web.UI;
using System.Collections;
using System.Globalization;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using Microsoft.ReportingServices.Interfaces;
using System.Xml;
using Prologika.RS.Extensibility.CustomDeliveryExtension;

namespace Prologika.RS.Extensibility.CustomDeliveryExtension
{
		/// <summary>
		/// The user facade of the Web Service Delivery Extension which will be used by the Report Manager.
		/// </summary>
		public class WebServiceDeliveryUIControl : System.Web.UI.WebControls.WebControl, ISubscriptionBaseUIUserControl
		{
			// Variables used to store information about the subscription being created
			private string             _wsdl					= null;
			private string             _methodName				= null;
      
			// Labels for UI controls
			internal const string      LABEL_WSDL				= "WSDL URL:";
			internal const string      LABEL_METHOD_NAME		= "Method Name:";
      
			// IDs used to refer to controls on the UI page.
			internal const string      CONTROLID_WSLD			= "idWSDL";
			internal const string      CONTROLID_METHOD_NAME	= "idMethodName";
      
			// Strings to enable validation to occur (client side validation needs JavaScript)
			internal const string      LANGUAGEATTRIBUTE = "language";
			internal const string      SCRIPTDEFAULTLANGUAGE = "Javascript";
			internal const string      SCRIPTTYPEATTRIBUTE = "type";
			internal const string      SCRIPTDEFAULTTYPE = "text/Javascript";
			internal const string      SCRIPTTAG = "script";
			internal const string      ONCLICK = "onclick";

			// Used to keep track of whether we have values specified by the user
			private bool _hasUserData = false;
      
			#region Controls
			// Controls used on the UI page
			private LiteralControl  _validatorScript = new LiteralControl();

			// HTML table variables
			private HtmlTable          		_outerTable = new HtmlTable();
			private HtmlTableRow       		_currentRow = null;
			private HtmlTableCell      		_currentCell = null;
			private HtmlGenericControl 		_pageLevelScript = new HtmlGenericControl(SCRIPTTAG);

			// Labels for controls
			private Label              		_labelWSDL = new Label();
			private Label              		_labelMethodName = new Label();

			// Control types
			private TextBox		       		_text_WSDL	= new TextBox();
			private TextBox            		_text_MethodName = new TextBox();

			// Placeholders for validators
			private PlaceHolder     		_invalidWSDL = new PlaceHolder();
			private PlaceHolder     		_invalidMethodName = new PlaceHolder();

			// Field validators for UI
			private RegularExpressionValidator 	_wsdlRegular = new RegularExpressionValidator();
			private RequiredFieldValidator 	_wsdlRequired = new RequiredFieldValidator();
			private RequiredFieldValidator 	_methodNameRequired = new RequiredFieldValidator();

			#endregion

			// Provider constructor
			public WebServiceDeliveryUIControl()
			{
        
				this.Init += new EventHandler(Control_Init);
				this.Load += new EventHandler(Control_Load);
				this.PreRender += new EventHandler(Control_PreRender);
			}

			#region Event Handlers

			private void Control_PreRender(object sender, EventArgs args)
			{
				// Use this event to enable/disable controls based on the 
				// user's selection before the control is rendered.
				// This extension does not use this event handler.
			}


			/// <summary>Perform all step needed when the control has been loaded</summary>
			/// <param name="sender"></param>
			/// <param name="args"></param>
			private void Control_Load(object sender, EventArgs args)
			{
				if (!Page.IsPostBack)
				{
					//if you have non-required Extension settings, initialize the values of the controls here
				}
			}


			/// <summary>
			/// Initialize the control
			/// </summary>
			/// <param name="sender"></param>
			/// <param name="args"></param>
			private void Control_Init(object sender, EventArgs args)
			{
				Controls.Add(_pageLevelScript);

				// Create page level script
				_pageLevelScript.Attributes.Add(LANGUAGEATTRIBUTE, SCRIPTDEFAULTLANGUAGE);
				_pageLevelScript.Attributes.Add(SCRIPTTYPEATTRIBUTE, SCRIPTDEFAULTTYPE);
				Controls.Add(_validatorScript);
				SetValidatorScript();

				// Build an empty row
				_currentRow = new HtmlTableRow();
				_outerTable.Rows.Add(_currentRow);
				_currentCell = new HtmlTableCell();
				_currentCell.NoWrap = true;
				_currentCell.Width = "10%";
				_currentRow.Cells.Add(_currentCell);
				_currentCell = new HtmlTableCell();
				_currentCell.NoWrap = true;
				_currentCell.Width = "25%";
				_currentRow.Cells.Add(_currentCell);			
				_currentCell = new HtmlTableCell();
				_currentCell.NoWrap = true;
				_currentCell.Width = "40%";
				_currentRow.Cells.Add(_currentCell);	
				_currentCell = new HtmlTableCell();
				_currentCell.NoWrap = true;
				_currentCell.Width = "100%";
				_currentRow.Cells.Add(_currentCell);	

				// Build a table row for entering the URL to the Web Service WSDL
				#region WSDL Textbox Row
				_currentRow = new HtmlTableRow();
				_outerTable.Rows.Add(_currentRow);

				// Add cell for the label
				_currentCell = new HtmlTableCell();
				_currentCell.NoWrap = true;
				_currentRow.Cells.Add(_currentCell);
         
				// Add label
				this._labelWSDL.Text = HttpUtility.HtmlEncode(LABEL_WSDL);
				_currentCell.Controls.Add(this._labelWSDL);

				// Add text box for entering value
				_currentCell = new HtmlTableCell();
				_currentCell.NoWrap = true;
				_currentCell.ColSpan = 2;
				_currentRow.Cells.Add(_currentCell);

				// set the control value from the configuration settings
				_wsdl = this.GetControlValue(Constants.CONFIG_WSDL);
				this._text_WSDL.Text = System.Convert.ToString(this._wsdl);

				_text_WSDL.ID = CONTROLID_WSLD;
				_text_WSDL.Style.Add("width", "100%");
				_text_WSDL.Style.Add("font-family", "Verdana, Sans-Serif");
				_text_WSDL.Style.Add("font-size", "x-small");

				// seat the control in a table cell
				_currentCell.Controls.Add(this._text_WSDL);

        
				_currentCell = new HtmlTableCell();
				_currentCell.NoWrap = true;
				_currentRow.Cells.Add(_currentCell);
         
				// Add Required Field validator 
				_currentCell.Controls.Add(this._invalidWSDL);
				this._wsdlRequired.Display = ValidatorDisplay.Dynamic;
				this._wsdlRequired.ControlToValidate = CONTROLID_WSLD;
				this._wsdlRequired.Controls.Add(ErrorMessage("Missing WSDL field.", true));
				this._invalidWSDL.Controls.Add(this._wsdlRequired);

				// Add Regular Expression validator
				this._wsdlRegular.Display = ValidatorDisplay.Dynamic;
				//this.m_wsdlRegular.ValidationExpression = @"http://([\w-]+\.)+[\w-]+(/[\w- ./?%&=]*)?";
				this._wsdlRegular.ValidationExpression = @"^(http://)?([^/]+)?(.*/)?(([^?#]+)?(\.[^?#]+)|([^?#]+)?)(\?[^#]*)?(#.*)?$";
				//this.m_wsdlRegular.ValidationExpression = @"http://([^/]+)?/?%&=]*)?";
				this._wsdlRegular.ControlToValidate = CONTROLID_WSLD;
				this._wsdlRegular.Controls.Add(ErrorMessage("Invalid URL.", true));
				this._invalidWSDL.Controls.Add(this._wsdlRegular);


				#endregion


				// Build a table row for the method name 
				#region Method Name Textbox Row
				_currentRow = new HtmlTableRow();
				_outerTable.Rows.Add(_currentRow);

				_currentCell = new HtmlTableCell();
				_currentCell.NoWrap = true;
				_currentRow.Cells.Add(_currentCell);
         
				this._labelMethodName.Text = HttpUtility.HtmlEncode(LABEL_METHOD_NAME);
				_currentCell.Controls.Add(this._labelMethodName);

				_currentCell = new HtmlTableCell();
				_currentCell.NoWrap = true;
				_currentCell.ColSpan = 2;
				_currentRow.Cells.Add(_currentCell);
         
				_methodName = this.GetControlValue(Constants.CONFIG_METHOD_NAME);
				this._text_MethodName.Text = System.Convert.ToString(this._methodName);

				_text_MethodName.ID = CONTROLID_METHOD_NAME;
				_text_MethodName.Style.Add("width", "100%");
				_text_MethodName.Style.Add("font-family", "Verdana, Sans-Serif");
				_text_MethodName.Style.Add("font-size", "x-small");

				_currentCell.Controls.Add(this._text_MethodName);

//				m_currentCell = new HtmlTableCell();
//				m_currentCell.NoWrap = true;
//				m_currentRow.Cells.Add(m_currentCell);
         
				_currentCell = new HtmlTableCell();
				_currentCell.NoWrap = true;
				_currentRow.Cells.Add(_currentCell);
         
				_currentCell.Controls.Add(this._invalidMethodName);
				this._methodNameRequired.Display = ValidatorDisplay.Dynamic;
				this._methodNameRequired.ControlToValidate = CONTROLID_METHOD_NAME;
				this._methodNameRequired.Controls.Add(ErrorMessage("Specify a value for the method name.", true));
				this._invalidMethodName.Controls.Add(this._methodNameRequired);


				#endregion

				_outerTable.Attributes.Add("class", "msrs-normal");
				_outerTable.CellPadding = 0;
				_outerTable.CellSpacing = 0;
				_outerTable.Width = "100%";
				Controls.Add(_outerTable);

			}
			/// <summary>
			///  Gets the default value for the control
			/// </summary>
			/// <param name="settingName"></param>
			/// <returns></returns>
			private string GetControlValue(string settingName)
			{
				string controlValue = null;

				if (!this._hasUserData)
				{

					// Grab the settings from the server
					foreach(Setting setting in this.m_rsInformation.ServerSettings)
					{
						if (setting.Name.Equals(settingName))
						{
							controlValue = setting.Value;
						}
					}
				}

				return controlValue;
			}

			#region VALIDATORSCRIPTFUNCTION
			private const string VALIDATORSCRIPTFUNCTION = 
				@"<script language='Javascript' type='text/Javascript'>
                function ValidateValueGreaterThanZero(source, args)
                {
                   var obj = document.all(source.controltovalidate);
   
               if ((obj.value != null) && (!isNaN(number(obj.value))) )
                    {
                  if (number(obj.value) <=0)
                  {
                     args.IsValid = false;
                  }
                    }

                  args.IsValid = true;
                }
                </script>
                ";
			#endregion
			private void SetValidatorScript()
			{
				_validatorScript.Text = VALIDATORSCRIPTFUNCTION;
			}

			protected Control ErrorMessage(string error, bool noWrap)
			{
				string imgUrl = Page.Request.ApplicationPath + "/images/line_err1.gif";
				HtmlImage htmlImg = new HtmlImage();
				htmlImg.Src = imgUrl;
				htmlImg.Alt = "Value specified contains an error.";
         
				HtmlTable tbl = new HtmlTable();
				tbl.Rows.Add(new HtmlTableRow());
				HtmlTableCell cell = new HtmlTableCell();
				cell.VAlign = "middle";
				//Note: you can reuse the Report Manager style sheet.
				cell.Attributes.Add("class", "msrs-validationerror"); 
				cell.Controls.Add(htmlImg);
				tbl.Rows[0].Cells.Add(cell);
				cell = new HtmlTableCell();
				cell.NoWrap = noWrap;
				cell.VAlign = "middle";
				cell.Attributes.Add("class", "msrs-validationerror");
				cell.Controls.Add(new LiteralControl(HttpUtility.HtmlEncode(error)));
				tbl.Rows[0].Cells.Add(cell);
				return tbl;
			}


			#endregion

			#region IExtension methods
			public String LocalizedName
			{
				get
				{
					return Constants.EXTENSION_NAME;
				}
			}

			public void SetConfiguration(String configInfo)
			{
				CultureInfo info = System.Threading.Thread.CurrentThread.CurrentCulture;
				try
				{
					//no configuration data for the web service delivery UI.
				}
				catch (Exception e)
				{
					throw new Exception(e.Message, null);
				}
				finally
				{
					System.Threading.Thread.CurrentThread.CurrentCulture = info;
				}
			}

			#endregion

			#region ISubscriptionBaseUIUserControl methods

			private bool m_isPrivilegedUser = false;
			public bool IsPrivilegedUser
			{
				get
				{
					return m_isPrivilegedUser;
				}
				set
				{
					m_isPrivilegedUser = value;
				}
			}

			// Validate that all selected information is correct
			public bool Validate()
			{
				// Nothing additional to validate
				return true;
			}

			// Get and Set the user data
			public Setting[] UserData
			{
				get
				{
					SubscriptionData data = new SubscriptionData();
					data.WSDL = this._text_WSDL.Text;
					data.methodName = this._text_MethodName.Text;
					return data.ToSettingArray();
				}

				set
				{
					this._hasUserData = true;
					SubscriptionData data = new SubscriptionData();
					data.FromSettings(value);
					this._wsdl = data.WSDL;
					this._methodName = data.methodName;
					this._text_MethodName.Text = this._methodName; 
				}
			}

			// Get the description that displays for the subscription
			public String Description
			{
				get
				{
					return "Delivers the report to a web service";
				}
			}

			private IDeliveryReportServerInformation m_rsInformation = null;
			public IDeliveryReportServerInformation ReportServerInformation
			{
				set
				{
					m_rsInformation = value;
				}
				get
				{
					return m_rsInformation;
				}
			}

			#endregion
		}
}
