using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Data;
using System.Windows.Forms;
using Microsoft.ReportDesigner.Design;
using Microsoft.ReportingServices.Interfaces;

namespace Prologika.RS.Extensibility.ProgressTrackerCRI
{
	/// <summary>
	/// ProgressBar control
	/// </summary>
    public class ProgressTracker
	{
		/// <summary> 
		/// Class members
		/// </summary>

		private int				_alpha;
		private float			_max;
		private float			_min;
		private float			_value;
		private Color			_progressColor;
		private Color			_borderColor;
		private bool			_showValue = true;
        private Font            _font;
        private int             _width = 200;
        private int             _height = 65;
        private string          _hyperlink = String.Empty;


		/// <summary>
		/// ProgressTracker Control
		/// </summary>
		public ProgressTracker() : base()
		{
			this._alpha = 255;
			this._progressColor = Color.Gold;
			this._max = 1;
			this._value = 0F;
			this._min = -1;
			this._borderColor = Color.Gray;
			this._showValue = true;
            
		}

		#region Public Properties

		public Color ProgressColor
		{
			get
			{
				return this._progressColor;
			}
			set
			{
				if ( this._progressColor != value )
				{
					this._progressColor = value;
				}
			}
		}

		/// <summary>
		/// Border color
		/// </summary>
		public Color BorderColor
		{
			get
			{
				return this._borderColor;
			}
			set
			{
				if ( this._borderColor != value )
				{
					this._borderColor = value;
				}
			}
		}

        /// <summary>
        /// Font
        /// </summary>
        [Category("ProgressTracker"), DefaultValue(typeof(Font), "Arial Narrow")]
        public Font Font
        {
            get
            {
                return this._font;
            }
            set
            {
                this._font = value;
            }
        }
		/// <summary>
		/// Maximum Value
		/// </summary>
		public float Maximum
		{
			get
			{
				return this._max;
			}
			set
			{
				if ( this._max != value )
				{
					this._max = value;
				}
                
			}
		}

		/// <summary>
		/// Minimum Value
		/// </summary>
		public float Minimum
		{
			get
			{
				return this._min;
			}
			set
			{
				if ( this._min != value )
				{
					this._min = value;
                }
                
            }
		}

		/// <summary>
		/// Progress value
		/// </summary>
		public float Value
		{
			get
			{
				return this._value ;
			}
			set
			{
				if ( this._value != value )
				{
					this._value = value;
				}
			}
		}

		/// <summary>
		/// Customize the transparency
		/// </summary>
		public int Alpha
		{
			get
			{
				return this._alpha;
			}
			set
			{
				if ( this._alpha != value )
				{
					this._alpha = value;
				}
			}
		}

		/// <summary>
        /// When True, shows the progress value
		/// </summary>
		public bool ShowValue
		{
			get
			{
				return this._showValue;
			}
			set
			{
				if ( this._showValue != value )
				{
					this._showValue = value;
				}
			}
		}

        /// <summary>
        /// Width of the control.
        /// </summary>
        public int Width
        {
            get { return _width; }
            set { _width = value; }
        }

        /// <summary>
        /// Height of the control.
        /// </summary>
        public int Height
        {
            get { return _height; }
            set { _height = value; }
        }
        /// <summary>
        /// Height of the control.
        /// </summary>
        public string Hyperlink
        {
            get { return _hyperlink; }
            set { _hyperlink = value; }
        }
		#endregion

		#region Painting

	    /// <summary>
		/// Do the actual drawing here
		/// </summary>
		/// <param name="g"></param>
		/// <param name="foreColor"></param>
		public void DrawControl(Graphics g)
		{
			bool outLine = this._borderColor != Color.Transparent;
            Rectangle bar = new Rectangle(0, 0, this.Width, this.Height);

			bar.Inflate(-20, -5);
            DrawingUtils.DrawBar (g, bar, Color.FromArgb(this.Alpha, Color.LightGray), this.BorderColor, outLine);

 			if ( this.Value >= this.Minimum && this.Value <= this.Maximum )
			{
				float value = bar.Width * (( this.Value - this.Minimum ) / ( this.Maximum - this.Minimum));
				Rectangle progress = Rectangle.FromLTRB(bar.Left, bar.Top, bar.Left + (int) value, bar.Bottom);

                DrawingUtils.DrawBar(g, progress, Color.FromArgb(this.Alpha, this.ProgressColor), this.BorderColor, outLine);

				if ( this._showValue && progress.Height > 10 )
				{
					StringFormat format = new StringFormat();
					format.Alignment = StringAlignment.Center;
					format.LineAlignment = StringAlignment.Center;
					g.DrawString(this._value.ToString("F2"), this.Font, Brushes.Black, bar, format);
					format.Dispose();
				}
			}
        }
        #endregion Paint Code
	}
}
